Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5697)

Unified Diff: chrome/browser/password_manager/native_backend_libsecret.cc

Issue 2716583003: Rename Origin.unique() to opaque().
Patch Set: Update new uses post-rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/password_manager/native_backend_libsecret.cc
diff --git a/chrome/browser/password_manager/native_backend_libsecret.cc b/chrome/browser/password_manager/native_backend_libsecret.cc
index 36c42291bbdd79bef988212c775c053ab00fc402..8939fa9db377eae450cc80c0c3af34d5472cc035 100644
--- a/chrome/browser/password_manager/native_backend_libsecret.cc
+++ b/chrome/browser/password_manager/native_backend_libsecret.cc
@@ -375,9 +375,9 @@ bool NativeBackendLibsecret::RawAddLogin(const PasswordForm& form) {
"date_synced", base::Int64ToString(date_synced).c_str(),
"display_name", UTF16ToUTF8(form.display_name).c_str(),
"avatar_url", form.icon_url.spec().c_str(),
// We serialize unique origins as "", in order to make other systems that
// read from the login database happy. https://crbug.com/591310
- "federation_url", form.federation_origin.unique()
+ "federation_url", form.federation_origin.opaque()
? ""
: form.federation_origin.Serialize().c_str(),
"should_skip_zero_click", form.skip_zero_click,
@@ -375,9 +375,9 @@ bool NativeBackendLibsecret::RawAddLogin(const PasswordForm& form) {
"display_name", UTF16ToUTF8(form.display_name).c_str(),
"avatar_url", form.icon_url.spec().c_str(),
- // We serialize unique origins as "", in order to make other systems that
+ // We serialize opaque origins as "", in order to make other systems that
// read from the login database happy. https://crbug.com/591310

Powered by Google App Engine
This is Rietveld 408576698